@@ -22,7 +22,7 @@ def sensor_grid_simple(directory):
 
 def sensor_grid_detailed(directory):
     room1 = Room.from_box('Tiny_House_Room', 5, 10, 3)
-    sensor_grid, mesh = room1.properties.radiance.generate_sensor_grid(1, 1, 1)
+    sensor_grid = room1.properties.radiance.generate_sensor_grid(1, 1, 1)
     sensor_grid.display_name = 'Tiny House Sensor Grid'
     dest_file = os.path.join(directory, 'sensor_grid_detailed.json')
     with open(dest_file, 'w') as fp:
