@@ -13,11 +13,6 @@ def test_model_complete_multi_zone_office():
     Model.parse_file(file_path)
 
 
-def test_model_complete_multiroom_radiance():
-    file_path = os.path.join(target_folder, 'model_complete_multiroom_radiance.json')
-    Model.parse_file(file_path)
-
-
 def test_model_complete_single_zone_office():
     file_path = os.path.join(target_folder, 'model_complete_single_zone_office.json')
     Model.parse_file(file_path)
@@ -33,6 +28,21 @@ def test_model_complete_patient_room():
     Model.parse_file(file_path)
 
 
+def test_model_complete_multiroom_radiance():
+    file_path = os.path.join(target_folder, 'model_complete_multiroom_radiance.json')
+    Model.parse_file(file_path)
+
+
+def test_model_radiance_grid_views():
+    file_path = os.path.join(target_folder, 'model_radiance_grid_views.json')
+    Model.parse_file(file_path)
+
+
+def test_model_radiance_dynamic_states():
+    file_path = os.path.join(target_folder, 'model_radiance_dynamic_states.json')
+    Model.parse_file(file_path)
+
+
 def test_model_energy_shoe_box():
     file_path = os.path.join(target_folder, 'model_energy_shoe_box.json')
     Model.parse_file(file_path)
@@ -78,6 +88,11 @@ def test_model_5vertex_sub_faces():
     Model.parse_file(file_path)
 
 
+def test_model_5vertex_sub_faces_interior():
+    file_path = os.path.join(target_folder, 'model_5vertex_sub_faces_interior.json')
+    Model.parse_file(file_path)
+
+
 def test_model_energy_properties_office():
     file_path = os.path.join(target_folder, 'model_energy_properties_office.json')
     ModelEnergyProperties.parse_file(file_path)
